# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcg.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import data_room_pb2 as data__room__pb2
from . import attestation_pb2 as attestation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tgcg.proto\x12\x03gcg\x1a\x0f\x64\x61ta_room.proto\x1a\x11\x61ttestation.proto\"\x86\x06\n\nGcgRequest\x12;\n\x15\x65xecuteComputeRequest\x18\x02 \x01(\x0b\x32\x1a.gcg.ExecuteComputeRequestH\x00\x12;\n\x15\x63reateDataRoomRequest\x18\x03 \x01(\x0b\x32\x1a.gcg.CreateDataRoomRequestH\x00\x12O\n\x1fpublishDatasetToDataRoomRequest\x18\x04 \x01(\x0b\x32$.gcg.PublishDatasetToDataRoomRequestH\x00\x12?\n\x17retrieveDataRoomRequest\x18\x05 \x01(\x0b\x32\x1c.gcg.RetrieveDataRoomRequestH\x00\x12?\n\x17retrieveAuditLogRequest\x18\x06 \x01(\x0b\x32\x1c.gcg.RetrieveAuditLogRequestH\x00\x12K\n\x1dretrieveDataRoomStatusRequest\x18\x07 \x01(\x0b\x32\".gcg.RetrieveDataRoomStatusRequestH\x00\x12G\n\x1bupdateDataRoomStatusRequest\x18\n \x01(\x0b\x32 .gcg.UpdateDataRoomStatusRequestH\x00\x12Q\n retrievePublishedDatasetsRequest\x18\x0b \x01(\x0b\x32%.gcg.RetrievePublishedDatasetsRequestH\x00\x12K\n\x1dremovePublishedDatasetRequest\x18\x0c \x01(\x0b\x32\".gcg.RemovePublishedDatasetRequestH\x00\x12\x31\n\x10jobStatusRequest\x18\r \x01(\x0b\x32\x15.gcg.JobStatusRequestH\x00\x12\x33\n\x11getResultsRequest\x18\x0e \x01(\x0b\x32\x16.gcg.GetResultsRequestH\x00\x42\r\n\x0bgcg_request\"\xfe\x06\n\x0bGcgResponse\x12\x11\n\x07\x66\x61ilure\x18\x01 \x01(\tH\x00\x12=\n\x16\x65xecuteComputeResponse\x18\x02 \x01(\x0b\x32\x1b.gcg.ExecuteComputeResponseH\x00\x12=\n\x16\x63reateDataRoomResponse\x18\x03 \x01(\x0b\x32\x1b.gcg.CreateDataRoomResponseH\x00\x12Q\n publishDatasetToDataRoomResponse\x18\x04 \x01(\x0b\x32%.gcg.PublishDatasetToDataRoomResponseH\x00\x12\x41\n\x18retrieveDataRoomResponse\x18\x05 \x01(\x0b\x32\x1d.gcg.RetrieveDataRoomResponseH\x00\x12\x41\n\x18retrieveAuditLogResponse\x18\x06 \x01(\x0b\x32\x1d.gcg.RetrieveAuditLogResponseH\x00\x12M\n\x1eretrieveDataRoomStatusResponse\x18\x07 \x01(\x0b\x32#.gcg.RetrieveDataRoomStatusResponseH\x00\x12I\n\x1cupdateDataRoomStatusResponse\x18\n \x01(\x0b\x32!.gcg.UpdateDataRoomStatusResponseH\x00\x12S\n!retrievePublishedDatasetsResponse\x18\x0b \x01(\x0b\x32&.gcg.RetrievePublishedDatasetsResponseH\x00\x12M\n\x1eremovePublishedDatasetResponse\x18\x0c \x01(\x0b\x32#.gcg.RemovePublishedDatasetResponseH\x00\x12\x33\n\x11jobStatusResponse\x18\r \x01(\x0b\x32\x16.gcg.JobStatusResponseH\x00\x12?\n\x17getResultsResponseChunk\x18\x0e \x01(\x0b\x32\x1c.gcg.GetResultsResponseChunkH\x00\x12\x41\n\x18getResultsResponseFooter\x18\x0f \x01(\x0b\x32\x1d.gcg.GetResultsResponseFooterH\x00\x42\x0e\n\x0cgcg_response\"M\n\x15\x43reateDataRoomRequest\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\x12\r\n\x05scope\x18\x02 \x01(\x0c\"\x8c\x01\n\x16\x43reateDataRoomResponse\x12\x14\n\ndataRoomId\x18\x01 \x01(\x0cH\x00\x12?\n\x17\x64\x61taRoomValidationError\x18\x02 \x01(\x0b\x32\x1c.gcg.DataRoomValidationErrorH\x00\x42\x1b\n\x19\x63reate_data_room_response\"\xb0\x03\n\x17\x44\x61taRoomValidationError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x1d\n\x10\x63omputeNodeIndex\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x18\n\x0b\x63olumnIndex\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x17\n\ntableIndex\x18\x04 \x01(\x04H\x02\x88\x01\x01\x12 \n\x13userPermissionIndex\x18\x05 \x01(\x04H\x03\x88\x01\x01\x12\x1c\n\x0fpermissionIndex\x18\x06 \x01(\x04H\x04\x88\x01\x01\x12*\n\x1d\x61ttestationSpecificationIndex\x18\x07 \x01(\x04H\x05\x88\x01\x01\x12&\n\x19\x61uthenticationMethodIndex\x18\x08 \x01(\x04H\x06\x88\x01\x01\x42\x13\n\x11_computeNodeIndexB\x0e\n\x0c_columnIndexB\r\n\x0b_tableIndexB\x16\n\x14_userPermissionIndexB\x12\n\x10_permissionIndexB \n\x1e_attestationSpecificationIndexB\x1c\n\x1a_authenticationMethodIndex\"\x82\x01\n\x1fPublishDatasetToDataRoomRequest\x12\x13\n\x0b\x64\x61tasetHash\x18\x01 \x01(\x0c\x12\x12\n\ndataRoomId\x18\x02 \x01(\x0c\x12\x10\n\x08leafName\x18\x03 \x01(\t\x12\x15\n\rencryptionKey\x18\x04 \x01(\x0c\x12\r\n\x05scope\x18\x05 \x01(\x0c\"\"\n PublishDatasetToDataRoomResponse\"f\n\x15\x45xecuteComputeRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\x18\n\x10\x63omputeNodeNames\x18\x02 \x03(\t\x12\x10\n\x08isDryRun\x18\x03 \x01(\x08\x12\r\n\x05scope\x18\x04 \x01(\x0c\"\'\n\x16\x45xecuteComputeResponse\x12\r\n\x05jobId\x18\x01 \x01(\x0c\"!\n\x10JobStatusRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\"5\n\x11JobStatusResponse\x12 \n\x18\x63ompleteComputeNodeNames\x18\x01 \x03(\t\";\n\x11GetResultsRequest\x12\r\n\x05jobId\x18\x01 \x01(\x0c\x12\x17\n\x0f\x63omputeNodeName\x18\x02 \x01(\t\"\'\n\x17GetResultsResponseChunk\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x1a\n\x18GetResultsResponseFooter\"<\n\x17RetrieveDataRoomRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\"A\n\x18RetrieveDataRoomResponse\x12%\n\x08\x64\x61taRoom\x18\x01 \x01(\x0b\x32\x13.data_room.DataRoom\"<\n\x17RetrieveAuditLogRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\"\'\n\x18RetrieveAuditLogResponse\x12\x0b\n\x03log\x18\x01 \x01(\x0c\"B\n\x1dRetrieveDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\"E\n\x1eRetrieveDataRoomStatusResponse\x12#\n\x06status\x18\x01 \x01(\x0e\x32\x13.gcg.DataRoomStatus\"e\n\x1bUpdateDataRoomStatusRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\x12#\n\x06status\x18\x03 \x01(\x0e\x32\x13.gcg.DataRoomStatus\"\x1e\n\x1cUpdateDataRoomStatusResponse\"E\n RetrievePublishedDatasetsRequest\x12\x12\n\ndataRoomId\x18\x01 \x01(\x0c\x12\r\n\x05scope\x18\x02 \x01(\x0c\"Z\n\x10PublishedDataset\x12\x10\n\x08leafName\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12\x13\n\x0b\x64\x61tasetHash\x18\x04 \x01(\x0c\"U\n!RetrievePublishedDatasetsResponse\x12\x30\n\x11publishedDatasets\x18\x01 \x03(\x0b\x32\x15.gcg.PublishedDataset\"Z\n\x1dRemovePublishedDatasetRequest\x12\x12\n\ndataRoomId\x18\x02 \x01(\x0c\x12\x10\n\x08leafName\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\x0cJ\x04\x08\x01\x10\x02\" \n\x1eRemovePublishedDatasetResponse\"|\n\x10\x44riverTaskConfig\x12\x1f\n\x04noop\x18\x01 \x01(\x0b\x32\x0f.gcg.NoopConfigH\x00\x12\x31\n\rstaticContent\x18\x02 \x01(\x0b\x32\x18.gcg.StaticContentConfigH\x00\x42\x14\n\x12\x64river_task_config\"\x0c\n\nNoopConfig\"&\n\x13StaticContentConfig\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c*)\n\x0e\x44\x61taRoomStatus\x12\n\n\x06\x41\x63tive\x10\x00\x12\x0b\n\x07Stopped\x10\x01\x62\x06proto3')

_DATAROOMSTATUS = DESCRIPTOR.enum_types_by_name['DataRoomStatus']
DataRoomStatus = enum_type_wrapper.EnumTypeWrapper(_DATAROOMSTATUS)
Active = 0
Stopped = 1


_GCGREQUEST = DESCRIPTOR.message_types_by_name['GcgRequest']
_GCGRESPONSE = DESCRIPTOR.message_types_by_name['GcgResponse']
_CREATEDATAROOMREQUEST = DESCRIPTOR.message_types_by_name['CreateDataRoomRequest']
_CREATEDATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['CreateDataRoomResponse']
_DATAROOMVALIDATIONERROR = DESCRIPTOR.message_types_by_name['DataRoomValidationError']
_PUBLISHDATASETTODATAROOMREQUEST = DESCRIPTOR.message_types_by_name['PublishDatasetToDataRoomRequest']
_PUBLISHDATASETTODATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['PublishDatasetToDataRoomResponse']
_EXECUTECOMPUTEREQUEST = DESCRIPTOR.message_types_by_name['ExecuteComputeRequest']
_EXECUTECOMPUTERESPONSE = DESCRIPTOR.message_types_by_name['ExecuteComputeResponse']
_JOBSTATUSREQUEST = DESCRIPTOR.message_types_by_name['JobStatusRequest']
_JOBSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['JobStatusResponse']
_GETRESULTSREQUEST = DESCRIPTOR.message_types_by_name['GetResultsRequest']
_GETRESULTSRESPONSECHUNK = DESCRIPTOR.message_types_by_name['GetResultsResponseChunk']
_GETRESULTSRESPONSEFOOTER = DESCRIPTOR.message_types_by_name['GetResultsResponseFooter']
_RETRIEVEDATAROOMREQUEST = DESCRIPTOR.message_types_by_name['RetrieveDataRoomRequest']
_RETRIEVEDATAROOMRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveDataRoomResponse']
_RETRIEVEAUDITLOGREQUEST = DESCRIPTOR.message_types_by_name['RetrieveAuditLogRequest']
_RETRIEVEAUDITLOGRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveAuditLogResponse']
_RETRIEVEDATAROOMSTATUSREQUEST = DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusRequest']
_RETRIEVEDATAROOMSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['RetrieveDataRoomStatusResponse']
_UPDATEDATAROOMSTATUSREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusRequest']
_UPDATEDATAROOMSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataRoomStatusResponse']
_RETRIEVEPUBLISHEDDATASETSREQUEST = DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetsRequest']
_PUBLISHEDDATASET = DESCRIPTOR.message_types_by_name['PublishedDataset']
_RETRIEVEPUBLISHEDDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['RetrievePublishedDatasetsResponse']
_REMOVEPUBLISHEDDATASETREQUEST = DESCRIPTOR.message_types_by_name['RemovePublishedDatasetRequest']
_REMOVEPUBLISHEDDATASETRESPONSE = DESCRIPTOR.message_types_by_name['RemovePublishedDatasetResponse']
_DRIVERTASKCONFIG = DESCRIPTOR.message_types_by_name['DriverTaskConfig']
_NOOPCONFIG = DESCRIPTOR.message_types_by_name['NoopConfig']
_STATICCONTENTCONFIG = DESCRIPTOR.message_types_by_name['StaticContentConfig']
GcgRequest = _reflection.GeneratedProtocolMessageType('GcgRequest', (_message.Message,), {
  'DESCRIPTOR' : _GCGREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GcgRequest)
  })
_sym_db.RegisterMessage(GcgRequest)

GcgResponse = _reflection.GeneratedProtocolMessageType('GcgResponse', (_message.Message,), {
  'DESCRIPTOR' : _GCGRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GcgResponse)
  })
_sym_db.RegisterMessage(GcgResponse)

CreateDataRoomRequest = _reflection.GeneratedProtocolMessageType('CreateDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateDataRoomRequest)
  })
_sym_db.RegisterMessage(CreateDataRoomRequest)

CreateDataRoomResponse = _reflection.GeneratedProtocolMessageType('CreateDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.CreateDataRoomResponse)
  })
_sym_db.RegisterMessage(CreateDataRoomResponse)

DataRoomValidationError = _reflection.GeneratedProtocolMessageType('DataRoomValidationError', (_message.Message,), {
  'DESCRIPTOR' : _DATAROOMVALIDATIONERROR,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.DataRoomValidationError)
  })
_sym_db.RegisterMessage(DataRoomValidationError)

PublishDatasetToDataRoomRequest = _reflection.GeneratedProtocolMessageType('PublishDatasetToDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATASETTODATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishDatasetToDataRoomRequest)
  })
_sym_db.RegisterMessage(PublishDatasetToDataRoomRequest)

PublishDatasetToDataRoomResponse = _reflection.GeneratedProtocolMessageType('PublishDatasetToDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHDATASETTODATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishDatasetToDataRoomResponse)
  })
_sym_db.RegisterMessage(PublishDatasetToDataRoomResponse)

ExecuteComputeRequest = _reflection.GeneratedProtocolMessageType('ExecuteComputeRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTECOMPUTEREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeRequest)
  })
_sym_db.RegisterMessage(ExecuteComputeRequest)

ExecuteComputeResponse = _reflection.GeneratedProtocolMessageType('ExecuteComputeResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTECOMPUTERESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.ExecuteComputeResponse)
  })
_sym_db.RegisterMessage(ExecuteComputeResponse)

JobStatusRequest = _reflection.GeneratedProtocolMessageType('JobStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.JobStatusRequest)
  })
_sym_db.RegisterMessage(JobStatusRequest)

JobStatusResponse = _reflection.GeneratedProtocolMessageType('JobStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.JobStatusResponse)
  })
_sym_db.RegisterMessage(JobStatusResponse)

GetResultsRequest = _reflection.GeneratedProtocolMessageType('GetResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsRequest)
  })
_sym_db.RegisterMessage(GetResultsRequest)

GetResultsResponseChunk = _reflection.GeneratedProtocolMessageType('GetResultsResponseChunk', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSECHUNK,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsResponseChunk)
  })
_sym_db.RegisterMessage(GetResultsResponseChunk)

GetResultsResponseFooter = _reflection.GeneratedProtocolMessageType('GetResultsResponseFooter', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSEFOOTER,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.GetResultsResponseFooter)
  })
_sym_db.RegisterMessage(GetResultsResponseFooter)

RetrieveDataRoomRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomRequest)

RetrieveDataRoomResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomResponse)

RetrieveAuditLogRequest = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveAuditLogRequest)
  })
_sym_db.RegisterMessage(RetrieveAuditLogRequest)

RetrieveAuditLogResponse = _reflection.GeneratedProtocolMessageType('RetrieveAuditLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEAUDITLOGRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveAuditLogResponse)
  })
_sym_db.RegisterMessage(RetrieveAuditLogResponse)

RetrieveDataRoomStatusRequest = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomStatusRequest)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusRequest)

RetrieveDataRoomStatusResponse = _reflection.GeneratedProtocolMessageType('RetrieveDataRoomStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEDATAROOMSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrieveDataRoomStatusResponse)
  })
_sym_db.RegisterMessage(RetrieveDataRoomStatusResponse)

UpdateDataRoomStatusRequest = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.UpdateDataRoomStatusRequest)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusRequest)

UpdateDataRoomStatusResponse = _reflection.GeneratedProtocolMessageType('UpdateDataRoomStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAROOMSTATUSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.UpdateDataRoomStatusResponse)
  })
_sym_db.RegisterMessage(UpdateDataRoomStatusResponse)

RetrievePublishedDatasetsRequest = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETSREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrievePublishedDatasetsRequest)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetsRequest)

PublishedDataset = _reflection.GeneratedProtocolMessageType('PublishedDataset', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHEDDATASET,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.PublishedDataset)
  })
_sym_db.RegisterMessage(PublishedDataset)

RetrievePublishedDatasetsResponse = _reflection.GeneratedProtocolMessageType('RetrievePublishedDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVEPUBLISHEDDATASETSRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RetrievePublishedDatasetsResponse)
  })
_sym_db.RegisterMessage(RetrievePublishedDatasetsResponse)

RemovePublishedDatasetRequest = _reflection.GeneratedProtocolMessageType('RemovePublishedDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPUBLISHEDDATASETREQUEST,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RemovePublishedDatasetRequest)
  })
_sym_db.RegisterMessage(RemovePublishedDatasetRequest)

RemovePublishedDatasetResponse = _reflection.GeneratedProtocolMessageType('RemovePublishedDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPUBLISHEDDATASETRESPONSE,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.RemovePublishedDatasetResponse)
  })
_sym_db.RegisterMessage(RemovePublishedDatasetResponse)

DriverTaskConfig = _reflection.GeneratedProtocolMessageType('DriverTaskConfig', (_message.Message,), {
  'DESCRIPTOR' : _DRIVERTASKCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.DriverTaskConfig)
  })
_sym_db.RegisterMessage(DriverTaskConfig)

NoopConfig = _reflection.GeneratedProtocolMessageType('NoopConfig', (_message.Message,), {
  'DESCRIPTOR' : _NOOPCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.NoopConfig)
  })
_sym_db.RegisterMessage(NoopConfig)

StaticContentConfig = _reflection.GeneratedProtocolMessageType('StaticContentConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATICCONTENTCONFIG,
  '__module__' : 'gcg_pb2'
  # @@protoc_insertion_point(class_scope:gcg.StaticContentConfig)
  })
_sym_db.RegisterMessage(StaticContentConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATAROOMSTATUS._serialized_start=3981
  _DATAROOMSTATUS._serialized_end=4022
  _GCGREQUEST._serialized_start=55
  _GCGREQUEST._serialized_end=829
  _GCGRESPONSE._serialized_start=832
  _GCGRESPONSE._serialized_end=1726
  _CREATEDATAROOMREQUEST._serialized_start=1728
  _CREATEDATAROOMREQUEST._serialized_end=1805
  _CREATEDATAROOMRESPONSE._serialized_start=1808
  _CREATEDATAROOMRESPONSE._serialized_end=1948
  _DATAROOMVALIDATIONERROR._serialized_start=1951
  _DATAROOMVALIDATIONERROR._serialized_end=2383
  _PUBLISHDATASETTODATAROOMREQUEST._serialized_start=2386
  _PUBLISHDATASETTODATAROOMREQUEST._serialized_end=2516
  _PUBLISHDATASETTODATAROOMRESPONSE._serialized_start=2518
  _PUBLISHDATASETTODATAROOMRESPONSE._serialized_end=2552
  _EXECUTECOMPUTEREQUEST._serialized_start=2554
  _EXECUTECOMPUTEREQUEST._serialized_end=2656
  _EXECUTECOMPUTERESPONSE._serialized_start=2658
  _EXECUTECOMPUTERESPONSE._serialized_end=2697
  _JOBSTATUSREQUEST._serialized_start=2699
  _JOBSTATUSREQUEST._serialized_end=2732
  _JOBSTATUSRESPONSE._serialized_start=2734
  _JOBSTATUSRESPONSE._serialized_end=2787
  _GETRESULTSREQUEST._serialized_start=2789
  _GETRESULTSREQUEST._serialized_end=2848
  _GETRESULTSRESPONSECHUNK._serialized_start=2850
  _GETRESULTSRESPONSECHUNK._serialized_end=2889
  _GETRESULTSRESPONSEFOOTER._serialized_start=2891
  _GETRESULTSRESPONSEFOOTER._serialized_end=2917
  _RETRIEVEDATAROOMREQUEST._serialized_start=2919
  _RETRIEVEDATAROOMREQUEST._serialized_end=2979
  _RETRIEVEDATAROOMRESPONSE._serialized_start=2981
  _RETRIEVEDATAROOMRESPONSE._serialized_end=3046
  _RETRIEVEAUDITLOGREQUEST._serialized_start=3048
  _RETRIEVEAUDITLOGREQUEST._serialized_end=3108
  _RETRIEVEAUDITLOGRESPONSE._serialized_start=3110
  _RETRIEVEAUDITLOGRESPONSE._serialized_end=3149
  _RETRIEVEDATAROOMSTATUSREQUEST._serialized_start=3151
  _RETRIEVEDATAROOMSTATUSREQUEST._serialized_end=3217
  _RETRIEVEDATAROOMSTATUSRESPONSE._serialized_start=3219
  _RETRIEVEDATAROOMSTATUSRESPONSE._serialized_end=3288
  _UPDATEDATAROOMSTATUSREQUEST._serialized_start=3290
  _UPDATEDATAROOMSTATUSREQUEST._serialized_end=3391
  _UPDATEDATAROOMSTATUSRESPONSE._serialized_start=3393
  _UPDATEDATAROOMSTATUSRESPONSE._serialized_end=3423
  _RETRIEVEPUBLISHEDDATASETSREQUEST._serialized_start=3425
  _RETRIEVEPUBLISHEDDATASETSREQUEST._serialized_end=3494
  _PUBLISHEDDATASET._serialized_start=3496
  _PUBLISHEDDATASET._serialized_end=3586
  _RETRIEVEPUBLISHEDDATASETSRESPONSE._serialized_start=3588
  _RETRIEVEPUBLISHEDDATASETSRESPONSE._serialized_end=3673
  _REMOVEPUBLISHEDDATASETREQUEST._serialized_start=3675
  _REMOVEPUBLISHEDDATASETREQUEST._serialized_end=3765
  _REMOVEPUBLISHEDDATASETRESPONSE._serialized_start=3767
  _REMOVEPUBLISHEDDATASETRESPONSE._serialized_end=3799
  _DRIVERTASKCONFIG._serialized_start=3801
  _DRIVERTASKCONFIG._serialized_end=3925
  _NOOPCONFIG._serialized_start=3927
  _NOOPCONFIG._serialized_end=3939
  _STATICCONTENTCONFIG._serialized_start=3941
  _STATICCONTENTCONFIG._serialized_end=3979
# @@protoc_insertion_point(module_scope)
