"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ContainerWorkerConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATIC_FIELD_NUMBER: builtins.int
    @property
    def static(self) -> global___StaticImage: ...
    def __init__(self,
        *,
        static : typing.Optional[global___StaticImage] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"configuration",b"configuration",u"static",b"static"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"configuration",b"configuration",u"static",b"static"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"configuration",b"configuration"]) -> typing.Optional[typing_extensions.Literal["static"]]: ...
global___ContainerWorkerConfiguration = ContainerWorkerConfiguration

class StaticImage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMAND_FIELD_NUMBER: builtins.int
    MOUNTPOINTS_FIELD_NUMBER: builtins.int
    OUTPUTPATH_FIELD_NUMBER: builtins.int
    INCLUDECONTAINERLOGSONERROR_FIELD_NUMBER: builtins.int
    @property
    def command(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    @property
    def mountPoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MountPoint]: ...
    outputPath: typing.Text = ...
    includeContainerLogsOnError: builtins.bool = ...
    def __init__(self,
        *,
        command : typing.Optional[typing.Iterable[typing.Text]] = ...,
        mountPoints : typing.Optional[typing.Iterable[global___MountPoint]] = ...,
        outputPath : typing.Text = ...,
        includeContainerLogsOnError : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"command",b"command",u"includeContainerLogsOnError",b"includeContainerLogsOnError",u"mountPoints",b"mountPoints",u"outputPath",b"outputPath"]) -> None: ...
global___StaticImage = StaticImage

class MountPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PATH_FIELD_NUMBER: builtins.int
    DEPENDENCY_FIELD_NUMBER: builtins.int
    path: typing.Text = ...
    dependency: typing.Text = ...
    def __init__(self,
        *,
        path : typing.Text = ...,
        dependency : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dependency",b"dependency",u"path",b"path"]) -> None: ...
global___MountPoint = MountPoint
