"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Fatquote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EPID_FIELD_NUMBER: builtins.int
    DCAP_FIELD_NUMBER: builtins.int
    NITRO_FIELD_NUMBER: builtins.int
    @property
    def epid(self) -> global___FatquoteEpid: ...
    @property
    def dcap(self) -> global___FatquoteDcap: ...
    @property
    def nitro(self) -> global___FatquoteNitro: ...
    def __init__(self,
        *,
        epid : typing.Optional[global___FatquoteEpid] = ...,
        dcap : typing.Optional[global___FatquoteDcap] = ...,
        nitro : typing.Optional[global___FatquoteNitro] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dcap",b"dcap",u"epid",b"epid",u"fatquote",b"fatquote",u"nitro",b"nitro"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dcap",b"dcap",u"epid",b"epid",u"fatquote",b"fatquote",u"nitro",b"nitro"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"fatquote",b"fatquote"]) -> typing.Optional[typing_extensions.Literal["epid","dcap","nitro"]]: ...
global___Fatquote = Fatquote

class FatquoteEpid(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IASRESPONSEBODY_FIELD_NUMBER: builtins.int
    IASCERTIFICATE_FIELD_NUMBER: builtins.int
    IASSIGNATURE_FIELD_NUMBER: builtins.int
    IASROOTCADER_FIELD_NUMBER: builtins.int
    iasResponseBody: builtins.bytes = ...
    iasCertificate: builtins.bytes = ...
    iasSignature: builtins.bytes = ...
    iasRootCaDer: builtins.bytes = ...
    def __init__(self,
        *,
        iasResponseBody : builtins.bytes = ...,
        iasCertificate : builtins.bytes = ...,
        iasSignature : builtins.bytes = ...,
        iasRootCaDer : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"iasCertificate",b"iasCertificate",u"iasResponseBody",b"iasResponseBody",u"iasRootCaDer",b"iasRootCaDer",u"iasSignature",b"iasSignature"]) -> None: ...
global___FatquoteEpid = FatquoteEpid

class FatquoteDcap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DCAPQUOTE_FIELD_NUMBER: builtins.int
    TCBINFO_FIELD_NUMBER: builtins.int
    QEIDENTITY_FIELD_NUMBER: builtins.int
    TCBSIGNCERT_FIELD_NUMBER: builtins.int
    QESIGNCERT_FIELD_NUMBER: builtins.int
    DCAPROOTCADER_FIELD_NUMBER: builtins.int
    dcapQuote: builtins.bytes = ...
    tcbInfo: builtins.bytes = ...
    qeIdentity: builtins.bytes = ...
    tcbSignCert: builtins.bytes = ...
    qeSignCert: builtins.bytes = ...
    dcapRootCaDer: builtins.bytes = ...
    def __init__(self,
        *,
        dcapQuote : builtins.bytes = ...,
        tcbInfo : builtins.bytes = ...,
        qeIdentity : builtins.bytes = ...,
        tcbSignCert : builtins.bytes = ...,
        qeSignCert : builtins.bytes = ...,
        dcapRootCaDer : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dcapQuote",b"dcapQuote",u"dcapRootCaDer",b"dcapRootCaDer",u"qeIdentity",b"qeIdentity",u"qeSignCert",b"qeSignCert",u"tcbInfo",b"tcbInfo",u"tcbSignCert",b"tcbSignCert"]) -> None: ...
global___FatquoteDcap = FatquoteDcap

class FatquoteNitro(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COSE_FIELD_NUMBER: builtins.int
    NITROROOTCADER_FIELD_NUMBER: builtins.int
    cose: builtins.bytes = ...
    nitroRootCaDer: builtins.bytes = ...
    def __init__(self,
        *,
        cose : builtins.bytes = ...,
        nitroRootCaDer : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"cose",b"cose",u"nitroRootCaDer",b"nitroRootCaDer"]) -> None: ...
global___FatquoteNitro = FatquoteNitro

class AttestationSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INTELEPID_FIELD_NUMBER: builtins.int
    INTELDCAP_FIELD_NUMBER: builtins.int
    AWSNITRO_FIELD_NUMBER: builtins.int
    @property
    def intelEpid(self) -> global___AttestationSpecificationIntelEpid: ...
    @property
    def intelDcap(self) -> global___AttestationSpecificationIntelDcap: ...
    @property
    def awsNitro(self) -> global___AttestationSpecificationAwsNitro: ...
    def __init__(self,
        *,
        intelEpid : typing.Optional[global___AttestationSpecificationIntelEpid] = ...,
        intelDcap : typing.Optional[global___AttestationSpecificationIntelDcap] = ...,
        awsNitro : typing.Optional[global___AttestationSpecificationAwsNitro] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"attestation_specification",b"attestation_specification",u"awsNitro",b"awsNitro",u"intelDcap",b"intelDcap",u"intelEpid",b"intelEpid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"attestation_specification",b"attestation_specification",u"awsNitro",b"awsNitro",u"intelDcap",b"intelDcap",u"intelEpid",b"intelEpid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"attestation_specification",b"attestation_specification"]) -> typing.Optional[typing_extensions.Literal["intelEpid","intelDcap","awsNitro"]]: ...
global___AttestationSpecification = AttestationSpecification

class AttestationSpecificationIntelEpid(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MRENCLAVE_FIELD_NUMBER: builtins.int
    IASROOTCADER_FIELD_NUMBER: builtins.int
    ACCEPT_DEBUG_FIELD_NUMBER: builtins.int
    ACCEPT_GROUP_OUT_OF_DATE_FIELD_NUMBER: builtins.int
    ACCEPT_CONFIGURATION_NEEDED_FIELD_NUMBER: builtins.int
    mrenclave: builtins.bytes = ...
    iasRootCaDer: builtins.bytes = ...
    accept_debug: builtins.bool = ...
    accept_group_out_of_date: builtins.bool = ...
    accept_configuration_needed: builtins.bool = ...
    def __init__(self,
        *,
        mrenclave : builtins.bytes = ...,
        iasRootCaDer : builtins.bytes = ...,
        accept_debug : builtins.bool = ...,
        accept_group_out_of_date : builtins.bool = ...,
        accept_configuration_needed : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"accept_configuration_needed",b"accept_configuration_needed",u"accept_debug",b"accept_debug",u"accept_group_out_of_date",b"accept_group_out_of_date",u"iasRootCaDer",b"iasRootCaDer",u"mrenclave",b"mrenclave"]) -> None: ...
global___AttestationSpecificationIntelEpid = AttestationSpecificationIntelEpid

class AttestationSpecificationIntelDcap(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MRENCLAVE_FIELD_NUMBER: builtins.int
    DCAPROOTCADER_FIELD_NUMBER: builtins.int
    ACCEPT_DEBUG_FIELD_NUMBER: builtins.int
    ACCEPT_OUT_OF_DATE_FIELD_NUMBER: builtins.int
    ACCEPT_CONFIGURATION_NEEDED_FIELD_NUMBER: builtins.int
    ACCEPT_SW_HARDENING_NEEDED_FIELD_NUMBER: builtins.int
    ACCEPT_REVOKED_FIELD_NUMBER: builtins.int
    mrenclave: builtins.bytes = ...
    dcapRootCaDer: builtins.bytes = ...
    accept_debug: builtins.bool = ...
    accept_out_of_date: builtins.bool = ...
    accept_configuration_needed: builtins.bool = ...
    accept_sw_hardening_needed: builtins.bool = ...
    accept_revoked: builtins.bool = ...
    def __init__(self,
        *,
        mrenclave : builtins.bytes = ...,
        dcapRootCaDer : builtins.bytes = ...,
        accept_debug : builtins.bool = ...,
        accept_out_of_date : builtins.bool = ...,
        accept_configuration_needed : builtins.bool = ...,
        accept_sw_hardening_needed : builtins.bool = ...,
        accept_revoked : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"accept_configuration_needed",b"accept_configuration_needed",u"accept_debug",b"accept_debug",u"accept_out_of_date",b"accept_out_of_date",u"accept_revoked",b"accept_revoked",u"accept_sw_hardening_needed",b"accept_sw_hardening_needed",u"dcapRootCaDer",b"dcapRootCaDer",u"mrenclave",b"mrenclave"]) -> None: ...
global___AttestationSpecificationIntelDcap = AttestationSpecificationIntelDcap

class AttestationSpecificationAwsNitro(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NITROROOTCADER_FIELD_NUMBER: builtins.int
    PCRS_FIELD_NUMBER: builtins.int
    nitroRootCaDer: builtins.bytes = ...
    @property
    def pcrs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
    def __init__(self,
        *,
        nitroRootCaDer : builtins.bytes = ...,
        pcrs : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"nitroRootCaDer",b"nitroRootCaDer",u"pcrs",b"pcrs"]) -> None: ...
global___AttestationSpecificationAwsNitro = AttestationSpecificationAwsNitro
